@@ -1,7 +1,7 @@
 #!/usr/local/bin/perl -w
 #
-# BNCFreq.pl version 0.09
-# (Updated 05/19/2004 -- Jason)
+# BNCFreq.pl version 0.12
+# (Last updated $Id: BNCFreq.pl,v 1.8 2004/10/29 19:25:42 sidz1979 Exp $)
 #
 # This program reads the BNCorpus and computes the frequency counts
 # for each synset in WordNet. These frequency counts are used by 
@@ -10,7 +10,7 @@
 # required by the WordNet::Similarity modules for computing semantic
 # relatedness.
 #
-# Copyright (c) 2002-2004
+# Copyright (c) 2004
 #
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse at d.umn.edu
@@ -580,20 +580,20 @@ sub printUsage
 # Subroutine to print the version information
 sub printVersion
 {
-    print "BNCFreq.pl version 0.09\n";
-    print "Copyright (c) 2002-2004 Ted Pedersen, Satanjeev Banerjee & Siddharth Patwardhan.\n";
+    print "BNCFreq.pl version 0.12\n";
+    print "Copyright (c) 2004 Ted Pedersen, Satanjeev Banerjee & Siddharth Patwardhan.\n";
 }
 
 __END__
 
 =head1 NAME
 
-rawtextFreq.pl
+BNCFreq.pl
 
 =head1 SYNOPSIS
 
-BNCFreq.pl [--compfile=COMPFILE --outfile=OUTFILE [--stopfile=STOPFILE] [--
-wnpath=WNPATH] [--resnik] [--smooth=SCHEME] PATH | --help -- version]
+BNCFreq.pl [--compfile=COMPFILE --outfile=OUTFILE [--stopfile=STOPFILE]
+ [--wnpath=WNPATH] [--resnik] [--smooth=SCHEME] PATH | --help --version]
 
 =head1 OPTIONS
 
